@@ -54,16 +54,8 @@ def get_latest_version(package_name: str) -> str:
         data = resp.json()
         return data["info"]["version"]
     except Exception:return None
-def check_rubka_version():
-    package_name = "rubka"
-    installed_version = get_installed_version(package_name)
-    if installed_version is None:return
-    latest_version = get_latest_version(package_name)
-    if latest_version is None:return
-    if installed_version != latest_version:
-        print(f"\npip install {package_name}=={latest_version}\n")
 
-check_rubka_version()
+
 def show_last_six_words(text):
     text = text.strip()
     return text[-6:]
